@@ -98,7 +98,11 @@ def driver_config_app():
         ),
         framework="flask",
         recipe_list=[
-            session.init(anti_csrf="VIA_TOKEN", cookie_domain="supertokens.io"),
+            session.init(
+                anti_csrf="VIA_TOKEN",
+                cookie_domain="supertokens.io",
+                get_token_transfer_method=lambda _, __, ___: "cookie",
+            ),
             emailpassword.init(
                 override=emailpassword.InputOverrideConfig(
                     apis=override_email_password_apis
@@ -189,13 +193,10 @@ def test_cookie_login_and_refresh(driver_config_app: Any):
     assert response_1.headers.get("anti-csrf") is not None
     assert cookies_1["sAccessToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
-    assert cookies_1["sIdRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sAccessToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sRefreshToken"]["path"] == TEST_DRIVER_CONFIG_REFRESH_TOKEN_PATH
-    assert cookies_1["sIdRefreshToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sAccessToken"]["httponly"]
     assert cookies_1["sRefreshToken"]["httponly"]
-    assert cookies_1["sIdRefreshToken"]["httponly"]
     assert (
         cookies_1["sAccessToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
@@ -204,37 +205,24 @@ def test_cookie_login_and_refresh(driver_config_app: Any):
         cookies_1["sRefreshToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
     )
-    assert (
-        cookies_1["sIdRefreshToken"]["samesite"].lower()
-        == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
-    )
 
     test_client = driver_config_app.test_client()
     test_client.set_cookie(
         "localhost", "sRefreshToken", cookies_1["sRefreshToken"]["value"]
     )
-    test_client.set_cookie(
-        "localhost", "sIdRefreshToken", cookies_1["sIdRefreshToken"]["value"]
-    )
     response_2 = test_client.post(
         "/refresh", headers={"anti-csrf": response_1.headers.get("anti-csrf")}
     )
     cookies_2 = extract_all_cookies(response_2)
     assert cookies_1["sAccessToken"]["value"] != cookies_2["sAccessToken"]["value"]
     assert cookies_1["sRefreshToken"]["value"] != cookies_2["sRefreshToken"]["value"]
-    assert (
-        cookies_1["sIdRefreshToken"]["value"] != cookies_2["sIdRefreshToken"]["value"]
-    )
     assert response_2.headers.get("anti-csrf") is not None
     assert cookies_2["sAccessToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_2["sRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
-    assert cookies_2["sIdRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_2["sAccessToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_2["sRefreshToken"]["path"] == TEST_DRIVER_CONFIG_REFRESH_TOKEN_PATH
-    assert cookies_2["sIdRefreshToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_2["sAccessToken"]["httponly"]
     assert cookies_2["sRefreshToken"]["httponly"]
-    assert cookies_2["sIdRefreshToken"]["httponly"]
     assert (
         cookies_2["sAccessToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
@@ -243,10 +231,6 @@ def test_cookie_login_and_refresh(driver_config_app: Any):
         cookies_2["sRefreshToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
     )
-    assert (
-        cookies_2["sIdRefreshToken"]["samesite"].lower()
-        == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
-    )
 
 
 def test_login_refresh_no_csrf(driver_config_app: Any):
@@ -274,13 +258,10 @@ def test_login_refresh_no_csrf(driver_config_app: Any):
     assert response_1.headers.get("anti-csrf") is not None
     assert cookies_1["sAccessToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
-    assert cookies_1["sIdRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sAccessToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sRefreshToken"]["path"] == TEST_DRIVER_CONFIG_REFRESH_TOKEN_PATH
-    assert cookies_1["sIdRefreshToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sAccessToken"]["httponly"]
     assert cookies_1["sRefreshToken"]["httponly"]
-    assert cookies_1["sIdRefreshToken"]["httponly"]
     assert (
         cookies_1["sAccessToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
@@ -289,18 +270,11 @@ def test_login_refresh_no_csrf(driver_config_app: Any):
         cookies_1["sRefreshToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
     )
-    assert (
-        cookies_1["sIdRefreshToken"]["samesite"].lower()
-        == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
-    )
 
     test_client = driver_config_app.test_client()
     test_client.set_cookie(
         "localhost", "sRefreshToken", cookies_1["sRefreshToken"]["value"]
     )
-    test_client.set_cookie(
-        "localhost", "sIdRefreshToken", cookies_1["sIdRefreshToken"]["value"]
-    )
 
     # post with csrf token -> no error
     result = test_client.post(
@@ -338,13 +312,10 @@ def test_login_logout(driver_config_app: Any):
     assert response_1.headers.get("anti-csrf") is not None
     assert cookies_1["sAccessToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
-    assert cookies_1["sIdRefreshToken"]["domain"] == TEST_DRIVER_CONFIG_COOKIE_DOMAIN
     assert cookies_1["sAccessToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sRefreshToken"]["path"] == TEST_DRIVER_CONFIG_REFRESH_TOKEN_PATH
-    assert cookies_1["sIdRefreshToken"]["path"] == TEST_DRIVER_CONFIG_ACCESS_TOKEN_PATH
     assert cookies_1["sAccessToken"]["httponly"]
     assert cookies_1["sRefreshToken"]["httponly"]
-    assert cookies_1["sIdRefreshToken"]["httponly"]
     assert (
         cookies_1["sAccessToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
@@ -353,18 +324,11 @@ def test_login_logout(driver_config_app: Any):
         cookies_1["sRefreshToken"]["samesite"].lower()
         == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
     )
-    assert (
-        cookies_1["sIdRefreshToken"]["samesite"].lower()
-        == TEST_DRIVER_CONFIG_COOKIE_SAME_SITE
-    )
 
     test_client = driver_config_app.test_client()
     test_client.set_cookie(
         "localhost", "sAccessToken", cookies_1["sAccessToken"]["value"]
     )
-    test_client.set_cookie(
-        "localhost", "sIdRefreshToken", cookies_1["sIdRefreshToken"]["value"]
-    )
 
     response_2 = test_client.post(
         "/logout", headers={"anti-csrf": response_1.headers.get("anti-csrf")}
@@ -405,9 +369,6 @@ def test_login_handle(driver_config_app: Any):
     test_client.set_cookie(
         "localhost", "sAccessToken", cookies_1["sAccessToken"]["value"]
     )
-    test_client.set_cookie(
-        "localhost", "sIdRefreshToken", cookies_1["sIdRefreshToken"]["value"]
-    )
 
     response_2 = test_client.get(
         "/handle", headers={"anti-csrf": response_1.headers.get("anti-csrf")}
@@ -437,3 +398,19 @@ def test_optional_session(driver_config_app: Any):
     dict_response = json.loads(response.data)
     assert response.status_code == 200
     assert dict_response["s"] == "empty session"
+
+
+from flask.wrappers import Response
+from supertokens_python.framework.flask.flask_response import (
+    FlaskResponse as SupertokensFlaskWrapper,
+)
+
+
+def test_remove_header_works():
+    response = Response()
+    st_response = SupertokensFlaskWrapper(response)
+
+    st_response.set_header("foo", "bar")
+    assert st_response.get_header("foo") == "bar"
+    st_response.remove_header("foo")
+    assert st_response.get_header("foo") is None
